@@ -1,4 +1,4 @@
-// $Id: xttpd.cc 5059 2013-07-21 12:41:26Z flaterco $
+// $Id: xttpd.cc 5749 2014-10-11 19:42:10Z flaterco $
 
 /*  xttpd  XTide web server.
 
@@ -18,11 +18,12 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "common.hh"
-#include "Graph.hh"
-#include "PixelatedGraph.hh"
-#include "RGBGraph.hh"
-#include "SVGGraph.hh"
+#include "libxtide/libxtide.hh"
+#include "libxtide/Graph.hh"
+#include "libxtide/PixelatedGraph.hh"
+#include "libxtide/RGBGraph.hh"
+#include "libxtide/SVGGraph.hh"
+using namespace libxtide;
 #include "ZoneIndex.hh"
 
 #include <sys/utsname.h>
