@@ -1,4 +1,4 @@
-// $Id: xxX.cc 5043 2013-07-10 23:01:53Z flaterco $
+// $Id: xxX.cc 5749 2014-10-11 19:42:10Z flaterco $
 
 /*  xxX  Globals for interfacing with X11.
 
@@ -19,7 +19,7 @@
 */
 
 #include "xtide.hh"
-#include "config.hh"
+#include "libxtide/config.hh"
 #include "icon_48x48_3color.xpm.hh"
 
 #ifdef HAVE_XAW3DXFT
